pub struct AllocatorStats<A> { /* private fields */ }Available on crate feature
unstable only.Expand description
Global allocator providing metrics on allocated memory
#[global_allocator]
static ALLOCATOR: AllocatorStats<std::alloc::System> = AllocatorStats::new(std::alloc::System);Setting this as the global allocator provides two counters:
elfo_allocated_bytes_total and elfo_deallocated_bytes_total, tracking
total allocated and deallocated memory in bytes.
Stability
This API is marked as unstable and is only available when the unstable
crate feature is enabled. This comes with no stability guarantees, and could be changed
or removed at any time.
Implementations
Sourceimpl<A> AllocatorStats<A>
impl<A> AllocatorStats<A>